# pixi-diff-to-markdown

`pixi-diff-to-markdown` is a tool that generates markdown from a JSON diff that's generated by `pixi update --json`.
It reads from the standard input and writes to the standard output.

```bash
pixi update --json | pixi-diff-to-markdown update > diff.md
```

Example output:

| Dependency | Before | After | Change |
| - | - | - | - |
| *new-package* |  | 0.10.1 | Added |
| *removed-package* | 0.10.1 |  | Removed |
| *bpy* | 0.10.1 | 2.10.1 | Major Upgrade |
| python | 0.10.0 | 0.10.1 | Patch Upgrade |
| *polars* | herads_0 | herads_1 | Only build string |

> [!TIP]
> The sorting of the tables is done by `environment`, `platform` and alphabetically.

## Installation

You can install `pixi-diff-to-markdown` using `pip` or `pixi`.

```bash
# via pixi
pixi global install pixi-diff-to-markdown
# via pip
pip install pixi-diff-to-markdown
```

## Configuration

Depending on your use case, you may want to configure the output of `pixi-diff-to-markdown`.
You can do this by creating a configuration section in `pixi.toml` or `pyproject.toml`.

```toml
# defaults
[tool.pixi-diff-to-markdown]
split-tables = "platform"
hide-tables = false
change-type-column = true
explicit-column = false
package-type-column = false
```

You can also override the configuration options by passing them as arguments to `pixi-diff-to-markdown`.

```bash
pixi update --json | pixi-diff-to-markdown update --split-tables=platform --explicit-column
```

### `split-tables`

Depending on the amount of `environments` and `platforms` you have in your `pixi.toml`, it might make sense to either split the tables or not.
For a large amount of `environments` and `platforms`, it might be easier to read the output if the tables are all merged into one.
`split-tables` can be set to one of the following values:

- `no`: Don't split the tables, they will all be merged into one ([example](./tests/resources/output/split-tables-no_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md)).
- `environment`: Create a table for each `environment` ([example](./tests/resources/output/split-tables-environment_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md)).
- `platform`: Split the tables by `platform` and `environment`, the most fine grained level ([example](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md)).

### `hide-tables`

Whether to hide the tables in a collapsible object ([example true](./tests/resources/output/split-tables-platform_hide-tables-True_change-type-True_explicit-type-False_package-type-False.md), [example false](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md))

### `change-type-column`

Whether to enable the `Change` column in the output ([example true](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md), [example false](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-False_explicit-type-False_package-type-False.md)).

### `explicit-column`

Whether to enable the `Explicit` column in the output ([example true](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-True_package-type-False.md), [example false](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md)).
If a dependency is explicitly defined in `pixi.toml`, it will be marked as `Explicit`. Otherwise, it will be marked as `Implicit`.

If this is set to `false`, the `Explicit` column will be omitted and the explicitly defined dependencies will be marked as *cursive*.

### `package-type-column`

Whether to enable the `Package Type` column in the output ([example true](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-False_package-type-True.md), [example false](./tests/resources/output/split-tables-platform_hide-tables-False_change-type-True_explicit-type-False_package-type-False.md)).
This column will show whether the dependency is a `conda` or `pypi` package.
